@@ -3,6 +3,11 @@
 #include <QDesktopServices>
 #include <QtGui>
 #include <QtWebKit>
+
+#include <QtGui/QX11Info>
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
+
 #include "contentwindow.h"
 
 /* Got ViewportItem and GraphicsView from maemobrowser in the qt examples. The
@@ -46,10 +51,8 @@ class ViewportItem : public QGraphicsWidget, public QAbstractKineticScroller {
 				case QEvent::GraphicsSceneMousePress:
 				case QEvent::GraphicsSceneMouseMove:
 				case QEvent::GraphicsSceneMouseRelease:
-				/*case QEvent::GraphicsSceneMouseDoubleClick:*/ {
 					res = handleMouseEvent(static_cast<QGraphicsSceneMouseEvent *>(e));
 					break;
-				}
 				default:
 					break;
 				}
@@ -60,6 +63,50 @@ class ViewportItem : public QGraphicsWidget, public QAbstractKineticScroller {
 			return res ? true : QGraphicsWidget::sceneEventFilter(i, e);
 		}
 
+		void keyPressEvent(QKeyEvent *e) {
+			int x, y, w, h;
+
+			switch(e->key()) {
+			case Qt::Key_Down:
+				y = m_widget->y() - 50;
+				h = (m_widget->size() - size()).height();
+				m_widget->setY(y < -h ? -h : y);
+				break;
+
+			case Qt::Key_Up:
+				y = m_widget->y() + 50;
+				m_widget->setY(y > 0 ? 0 : y);
+				break;
+
+			case Qt::Key_Right:
+				x = m_widget->x() - 50;
+				w = (m_widget->size() - size()).width();
+				m_widget->setX(x < -w ? -w : x);
+				break;
+
+			case Qt::Key_Left:
+				x = m_widget->x() + 50;
+				m_widget->setX(x > 0 ? 0 : x);
+				break;
+
+			case Qt::Key_F7:
+				if(qgraphicsitem_cast<QGraphicsWebView *>(m_widget)) {
+					QGraphicsWebView *wv = (QGraphicsWebView *)m_widget;
+					wv->setZoomFactor(wv->zoomFactor() * 1.25);
+					resizeWebViewToFrame();
+				}
+				break;
+
+			case Qt::Key_F8:
+				if(qgraphicsitem_cast<QGraphicsWebView *>(m_widget)) {
+					QGraphicsWebView *wv = (QGraphicsWebView *)m_widget;
+					wv->setZoomFactor(wv->zoomFactor() / 1.25);
+					resizeWebViewToFrame();
+				}
+				break;
+			}
+		}
+
 		QSize viewportSize() const {
 			return size().toSize();
 		}
@@ -163,6 +210,11 @@ ContentWindow::ContentWindow(QWidget *parent, Entry *e) : QMainWindow(parent) {
 	starred->setChecked((entry->flags & ENTRY_FLAG_STARRED));
 	menuBar()->addAction(starred);
 
+	shared = new QAction(tr("Shared"), this);
+	shared->setCheckable(true);
+	shared->setChecked((entry->flags & ENTRY_FLAG_SHARED));
+	menuBar()->addAction(shared);
+
 	keepUnread = new QAction(tr("Keep unread"), this);
 	keepUnread->setCheckable(true);
 	keepUnread->setEnabled((entry->flags & ENTRY_FLAG_LOCKED) == 0);
@@ -185,6 +237,10 @@ ContentWindow::ContentWindow(QWidget *parent, Entry *e) : QMainWindow(parent) {
 	webview->setHtml(entry->content);
 
 	setCentralWidget(gv);
+	gv->viewportItem()->setFocus();
+	gv->viewportItem()->grabKeyboard();
+
+	grabZoomKeys(true);
 }
 
 ContentWindow::~ContentWindow() {
@@ -206,9 +262,24 @@ void ContentWindow::seeOriginal() {
 }
 
 void ContentWindow::closeEvent(QCloseEvent *event) {
+	grabZoomKeys(false);
 	entry->markRead(!keepUnread->isChecked());
 	entry->markStar(starred->isChecked());
+	entry->markShared(shared->isChecked());
 	QMainWindow::closeEvent(event);
 }
 
+void ContentWindow::grabZoomKeys(bool grab) {
+	if(!winId())
+		return;
+
+	unsigned long val = (grab) ? 1 : 0;
+	Atom atom = XInternAtom(QX11Info::display(), "_HILDON_ZOOM_KEY_ATOM", False);
+	if(!atom)
+		return;
+
+	XChangeProperty (QX11Info::display(), winId(), atom, XA_INTEGER, 32, PropModeReplace,
+		reinterpret_cast<unsigned char *>(&val), 1);
+}
+
 #include "contentwindow.moc"
