@@ -123,7 +123,7 @@ void EntryListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
 	QRect rect = option.rect;
 	rect.adjust(20, 8, -20, -8);
 	QPoint topleft = rect.topLeft();
-	topleft.ry() += 2;
+	QPoint bottomleft = rect.bottomLeft();
 	rect.adjust(36, 0, 0, 0);
 
 	painter->save();
@@ -141,13 +141,25 @@ void EntryListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
 
 	painter->drawText(rect, Qt::AlignBottom | Qt::AlignLeft, e->author);
 
-	painter->drawText(rect, Qt::AlignBottom | Qt::AlignRight, e->published.toString());
+	QString date;
+	if(e->published.date() == QDateTime::currentDateTime().date())
+		date = e->published.time().toString(Qt::DefaultLocaleShortDate);
+	else
+		date = e->published.date().toString();
+
+	painter->drawText(rect, Qt::AlignBottom | Qt::AlignRight, date);
 
 	if(e->flags & ENTRY_FLAG_STARRED) {
 		QImage img = QImage(QLatin1String(":/images/star-1"));
 		painter->drawImage(topleft, img);
 	}
 
+	if(e->flags & ENTRY_FLAG_SHARED) {
+		QImage img = QImage(QLatin1String(":/images/shared-1"));
+		bottomleft.ry() -= img.height();
+		painter->drawImage(bottomleft, img);
+	}
+
 	painter->restore();
 }
 
