@@ -33,14 +33,14 @@ class Feed : public QObject {
 
 		GoogleReader *reader;
 
-		bool special;
+		int special;
 
 		void updateSubscription(Feed *feed);
 
 		Feed(GoogleReader *gr = NULL) : QObject() {
 			unread = 0;
 			reader = gr;
-			special = false;
+			special = 0;
 		}
 
 		void fetch(bool);
@@ -66,6 +66,7 @@ Q_DECLARE_METATYPE(Feed *)
 #define ENTRY_FLAG_READ		0x00000001
 #define ENTRY_FLAG_STARRED	0x00000002
 #define ENTRY_FLAG_LOCKED	0x00000004
+#define ENTRY_FLAG_SHARED	0x00000008
 
 class Entry : public QObject {
 	Q_OBJECT
@@ -101,10 +102,12 @@ class Entry : public QObject {
 
 		void markRead(bool);
 		void markStar(bool);
+		void markShared(bool);
 
 	private:
 		QBuffer postread;
 		QBuffer poststar;
+		QBuffer postshared;
 };
 
 Q_DECLARE_METATYPE(Entry *)
